@@ -17,12 +17,7 @@
 
 import logging
 import os
-try:
-    import pwd
-except ImportError:
-    WIN_PLATFORM = True
-else:
-    WIN_PLATFORM = False
+from getpass import getuser
 from socket import gaierror as sock_gaierror, error as sock_error
 
 from gevent import sleep, socket, Timeout as GTimeout
@@ -174,11 +169,7 @@ class BaseSSHClient(object):
                  identity_auth=True):
         self._auth_thread_pool = _auth_thread_pool
         self.host = host
-        self.user = user if user else None
-        if self.user is None and not WIN_PLATFORM:
-            self.user = pwd.getpwuid(os.geteuid()).pw_name
-        elif self.user is None and WIN_PLATFORM:
-            raise ValueError("Must provide user parameter on Windows")
+        self.user = user if user else getuser()
         self.password = password
         self.port = port if port else 22
         self.num_retries = num_retries
@@ -639,7 +630,7 @@ class BaseSSHClient(object):
             remote_path = os.path.join(remote_dir, file_name)
             local_path = os.path.join(local_dir, file_name)
             self.copy_remote_file(remote_path, local_path, sftp=sftp,
-                                  recurse=True)
+                                  recurse=True, encoding=encoding)
 
     def _make_local_dir(self, dirpath):
         if os.path.exists(dirpath):
