@@ -90,10 +90,8 @@ class LocalForwarder(Thread):
 
     def _cleanup_servers(self):
         for client in list(self._servers.keys()):
-            server = self._servers[client]
             if client.sock is None or client.sock.closed:
-                server.stop()
-                del self._servers[client]
+                self.cleanup_server(client)
 
     def run(self):
         """Thread runner ensures a non main hub has been created for all subsequent
@@ -118,6 +116,13 @@ class LocalForwarder(Thread):
                          exc_info=1)
             self.shutdown()
 
+    def cleanup_server(self, client):
+        """The purpose of this function is for a proxied client to notify the LocalForwarder that it
+         is shutting down and its corresponding server can also be shut down."""
+        server = self._servers[client]
+        server.stop()
+        del self._servers[client]
+
 
 class TunnelServer(StreamServer):
     """Local port forwarding server for tunneling connections from remote SSH server.
@@ -165,9 +170,12 @@ class TunnelServer(StreamServer):
         try:
             joinall((source, dest), raise_error=True)
         finally:
-            logger.debug("Closing channel and forward socket")
+            # Forward socket does not need to be closed here; StreamServer does it in do_close
+            logger.debug("Closing channel")
             self._client.close_channel(channel)
-            forward_sock.close()
+
+            # Disconnect client here to make sure it happens AFTER close_channel
+            self._client.disconnect()
 
     def _read_forward_sock(self, forward_sock, channel):
         while True:
